@@ -41,7 +41,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "httpda.h"
 #endif
 
-#define WSDL2H_VERSION "2.8.49"
+#define WSDL2H_VERSION "2.8.91"
 
 #ifdef WIN32
 # pragma warning(disable : 4996)
@@ -53,8 +53,6 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include <set>
 #include <map>
 
-using namespace std;
-
 struct ltstr
 { bool operator()(const char *s1, const char *s2) const
   { return strcmp(s1, s2) < 0;
@@ -69,9 +67,9 @@ struct eqstr
   }
 }; 
 
-typedef set<const char*, ltstr> SetOfString;
+typedef std::set<const char*, ltstr> SetOfString;
 
-typedef pair<const char*, const char*> Pair;
+typedef std::pair<const char*, const char*> Pair;
 
 struct ltpair
 { bool operator()(Pair s1, Pair s2) const
@@ -82,37 +80,45 @@ struct ltpair
   }
 };
 
-typedef map<const char*, const char*, ltstr> MapOfStringToString;
+typedef std::map<const char*, const char*, ltstr> MapOfStringToString;
 
-typedef map<Pair, const char*, ltpair> MapOfPairToString;
+typedef std::map<Pair, const char*, ltpair> MapOfPairToString;
 
-typedef map<const char*, size_t, ltstr> MapOfStringToNum;
+typedef std::map<const char*, size_t, ltstr> MapOfStringToNum;
 
-typedef vector<const char*> VectorOfString;
+typedef std::vector<const char*> VectorOfString;
 
 extern int _flag,
            aflag,
            bflag,
 	   cflag,
 	   c11flag,
+	   Dflag,
 	   dflag,
 	   eflag,
+	   Fflag,
 	   fflag,
 	   gflag,
 	   iflag,
 	   jflag,
 	   kflag,
-	   mflag,
+	   Lflag,
 	   Mflag,
-	   pflag,
+	   mflag,
+	   Oflag,
+	   Owflag,
 	   Pflag,
+	   pflag,
+           Qflag,
 	   Rflag,
 	   sflag,
+	   sflag,
 	   Uflag,
 	   uflag,
 	   vflag,
-	   wflag,
 	   Wflag,
+	   wflag,
+	   Xflag,
 	   xflag,
 	   yflag,
 	   zflag;
@@ -132,6 +138,7 @@ extern int proxy_port;
 
 extern const char *service_prefix;
 extern const char *schema_prefix;
+extern const char *soap_context;
 
 extern const char elementformat[];
 extern const char pointerformat[];
@@ -151,6 +158,7 @@ extern const char paraformat[];
 extern const char anonformat[];
 extern const char sizeparaformat[];
 extern const char pointertemplateparaformat[];
+extern const char derivedformat[];
 
 extern const char copyrightnotice[];
 extern const char licensenotice[];
