@@ -1,7 +1,7 @@
 /*
-	smdevp.c
+        smdevp.c
 
-	gSOAP interface for (signed) message digest
+        gSOAP interface for (signed) message digest
 
 gSOAP XML Web services tools
 Copyright (C) 2000-2015, Robert van Engelen, Genivia Inc., All Rights Reserved.
@@ -57,60 +57,61 @@ RSA_SHA1/224/256/384/512.
 
 A digest or signature algorithm is selected with one the following:
 
-- @ref SOAP_SMD_HMAC_MD5	to compute HMAC-MD5 message authentication code
-- @ref SOAP_SMD_HMAC_SHA1	to compute HMAC-SHA1 message authentication code
-- @ref SOAP_SMD_HMAC_SHA224	to compute HMAC-SHA224 message authentication code
-- @ref SOAP_SMD_HMAC_SHA256	to compute HMAC-SHA256 message authentication code
-- @ref SOAP_SMD_HMAC_SHA384	to compute HMAC-SHA384 message authentication code
-- @ref SOAP_SMD_HMAC_SHA512	to compute HMAC-SHA512 message authentication code
+- @ref SOAP_SMD_HMAC_MD5        to compute HMAC-MD5 message authentication code
+- @ref SOAP_SMD_HMAC_SHA1       to compute HMAC-SHA1 message authentication code
+- @ref SOAP_SMD_HMAC_SHA224     to compute HMAC-SHA224 message authentication code
+- @ref SOAP_SMD_HMAC_SHA256     to compute HMAC-SHA256 message authentication code
+- @ref SOAP_SMD_HMAC_SHA384     to compute HMAC-SHA384 message authentication code
+- @ref SOAP_SMD_HMAC_SHA512     to compute HMAC-SHA512 message authentication code
 
-- @ref SOAP_SMD_DGST_MD5	to compute MD5 128-bit digests
-- @ref SOAP_SMD_DGST_SHA1	to compute SHA1 160-bit digests
-- @ref SOAP_SMD_DGST_SHA224	to compute SHA224 224-bit digests
-- @ref SOAP_SMD_DGST_SHA256	to compute SHA256 256-bit digests
-- @ref SOAP_SMD_DGST_SHA384	to compute SHA384 384-bit digests
-- @ref SOAP_SMD_DGST_SHA512	to compute SHA512 512-bit digests
+- @ref SOAP_SMD_DGST_MD5        to compute MD5 128-bit digests
+- @ref SOAP_SMD_DGST_SHA1       to compute SHA1 160-bit digests
+- @ref SOAP_SMD_DGST_SHA224     to compute SHA224 224-bit digests
+- @ref SOAP_SMD_DGST_SHA256     to compute SHA256 256-bit digests
+- @ref SOAP_SMD_DGST_SHA384     to compute SHA384 384-bit digests
+- @ref SOAP_SMD_DGST_SHA512     to compute SHA512 512-bit digests
 
-- @ref SOAP_SMD_SIGN_DSA_SHA1	to compute DSA-SHA1 signatures
-- @ref SOAP_SMD_SIGN_DSA_SHA224	to compute DSA-SHA224 signatures
-- @ref SOAP_SMD_SIGN_DSA_SHA256	to compute DSA-SHA256 signatures
-- @ref SOAP_SMD_SIGN_DSA_SHA384	to compute DSA-SHA384 signatures
-- @ref SOAP_SMD_SIGN_DSA_SHA512	to compute DSA-SHA512 signatures
+- @ref SOAP_SMD_SIGN_DSA_SHA1   to compute DSA-SHA1 signatures
+- @ref SOAP_SMD_SIGN_DSA_SHA224 to compute DSA-SHA224 signatures
+- @ref SOAP_SMD_SIGN_DSA_SHA256 to compute DSA-SHA256 signatures
+- @ref SOAP_SMD_SIGN_DSA_SHA384 to compute DSA-SHA384 signatures
+- @ref SOAP_SMD_SIGN_DSA_SHA512 to compute DSA-SHA512 signatures
 
-- @ref SOAP_SMD_SIGN_RSA_SHA1	to compute RSA-SHA1 signatures
-- @ref SOAP_SMD_SIGN_RSA_SHA224	to compute RSA-SHA224 signatures
-- @ref SOAP_SMD_SIGN_RSA_SHA256	to compute RSA-SHA256 signatures
-- @ref SOAP_SMD_SIGN_RSA_SHA384	to compute RSA-SHA384 signatures
-- @ref SOAP_SMD_SIGN_RSA_SHA512	to compute RSA-SHA512 signatures
+- @ref SOAP_SMD_SIGN_RSA_SHA1   to compute RSA-SHA1 signatures
+- @ref SOAP_SMD_SIGN_RSA_SHA224 to compute RSA-SHA224 signatures
+- @ref SOAP_SMD_SIGN_RSA_SHA256 to compute RSA-SHA256 signatures
+- @ref SOAP_SMD_SIGN_RSA_SHA384 to compute RSA-SHA384 signatures
+- @ref SOAP_SMD_SIGN_RSA_SHA512 to compute RSA-SHA512 signatures
 
-- @ref SOAP_SMD_VRFY_DSA_SHA1	to verify DSA-SHA1 signatures
-- @ref SOAP_SMD_VRFY_DSA_SHA224	to verify DSA-SHA224 signatures
-- @ref SOAP_SMD_VRFY_DSA_SHA256	to verify DSA-SHA256 signatures
-- @ref SOAP_SMD_VRFY_DSA_SHA384	to verify DSA-SHA384 signatures
-- @ref SOAP_SMD_VRFY_DSA_SHA512	to verify DSA-SHA512 signatures
+- @ref SOAP_SMD_VRFY_DSA_SHA1   to verify DSA-SHA1 signatures
+- @ref SOAP_SMD_VRFY_DSA_SHA224 to verify DSA-SHA224 signatures
+- @ref SOAP_SMD_VRFY_DSA_SHA256 to verify DSA-SHA256 signatures
+- @ref SOAP_SMD_VRFY_DSA_SHA384 to verify DSA-SHA384 signatures
+- @ref SOAP_SMD_VRFY_DSA_SHA512 to verify DSA-SHA512 signatures
 
-- @ref SOAP_SMD_VRFY_RSA_SHA1	to verify RSA-SHA1 signatures
-- @ref SOAP_SMD_VRFY_RSA_SHA224	to verify RSA-SHA224 signatures
-- @ref SOAP_SMD_VRFY_RSA_SHA256	to verify RSA-SHA256 signatures
-- @ref SOAP_SMD_VRFY_RSA_SHA384	to verify RSA-SHA384 signatures
-- @ref SOAP_SMD_VRFY_RSA_SHA512	to verify RSA-SHA512 signatures
+- @ref SOAP_SMD_VRFY_RSA_SHA1   to verify RSA-SHA1 signatures
+- @ref SOAP_SMD_VRFY_RSA_SHA224 to verify RSA-SHA224 signatures
+- @ref SOAP_SMD_VRFY_RSA_SHA256 to verify RSA-SHA256 signatures
+- @ref SOAP_SMD_VRFY_RSA_SHA384 to verify RSA-SHA384 signatures
+- @ref SOAP_SMD_VRFY_RSA_SHA512 to verify RSA-SHA512 signatures
 
 Algorithm options:
 
-- @ref SOAP_SMD_PASSTHRU	to pass XML through the smdevp engine
+- @ref SOAP_SMD_PASSTHRU        to pass XML through the smdevp engine
 
 The smdevp engine wraps the EVP API with three new functions:
 
-- @ref soap_smd_init	to initialize the engine
-- @ref soap_smd_update	to update the state with a message part
-- @ref soap_smd_final	to compute the digest, signature, or verify a signature
-			and deallocate the engine
+- @ref soap_smd_init    to initialize the engine
+- @ref soap_smd_update  to update the state with a message part
+- @ref soap_smd_final   to compute the digest, signature, or verify a signature
+                        and to deallocate the engine
+- @ref soap_smd_cleanup to deallocate the engine
 
 A higher-level interface for computing (signed) message digests over
 messages produced by the gSOAP engine is defined by two new functions:
 
-- @ref soap_smd_begin	to start a digest or signature computation/verification
-- @ref soap_smd_end	to finalize the digest or signature and clean up
+- @ref soap_smd_begin   to start a digest or signature computation/verification
+- @ref soap_smd_end     to finalize the digest or signature and clean up
 
 Compile all source codes with -DWITH_OPENSSL and link with ssl and crypto
 libraries.
@@ -129,7 +130,8 @@ key applied to the SHA digest of the serialized object:
     fclose(fd);
     if (soap_smd_begin(soap, alg, key, 0)
      || soap_out_ns__Object(soap, "ns:Object", 0, &object, NULL))
-    { soap_smd_end(soap, NULL, NULL); // clean up
+    {
+      soap_smd_end(soap, NULL, NULL); // clean up
       soap_print_fault(soap, stderr);
     }
     else if (soap_smd_end(soap, sig, &siglen))
@@ -160,7 +162,8 @@ SOAP_SMD_PASSTHRU flag with the algorithm selection as follows:
      || soap_begin_send(soap)
      || soap_out_ns__Object(soap, "ns:Object", 0, &object, NULL) // save to "object.xml"
      || soap_end_send(soap))
-    { soap_smd_end(soap, NULL, NULL); // clean up
+    {
+      soap_smd_end(soap, NULL, NULL); // clean up
       soap_print_fault(soap, stderr);
     }
     else if (soap_smd_end(soap, sig, &siglen))
@@ -189,7 +192,8 @@ through the smdevp engine as follows:
     if (...) // key file contains public key?
       key = PEM_read_PUBKEY(fd, NULL, NULL, NULL);
     else // key file contains certificate
-    { X509 *cert = PEM_read_X509(fd, NULL, NULL, NULL);
+    {
+      X509 *cert = PEM_read_X509(fd, NULL, NULL, NULL);
       key = X509_get_pubkey(cert);
       X509_free(cert);
     }
@@ -199,7 +203,8 @@ through the smdevp engine as follows:
      || soap_begin_recv(soap)
      || soap_in_ns__Object(soap, "ns:Object", &object, NULL) == NULL
      || soap_end_recv(soap))
-    { soap_smd_end(soap, NULL, NULL); // clean up
+    {
+      soap_smd_end(soap, NULL, NULL); // clean up
       soap_print_fault(soap, stderr);
     }
     else if (soap_smd_end(soap, sig, &siglen))
@@ -225,14 +230,16 @@ file may contain both the (encrypted) private and public keys.
     if (...) // key file contains public key?
       key = PEM_read_PUBKEY(fd, NULL, NULL, NULL);
     else // key file contains certificate
-    { X509 *cert = PEM_read_X509(fd, NULL, NULL, NULL);
+    {
+      X509 *cert = PEM_read_X509(fd, NULL, NULL, NULL);
       key = X509_get_pubkey(cert);
       X509_free(cert);
     }
     fclose(fd);
     if (soap_smd_begin(soap, alg, key, 0)
      || soap_out_ns__Object(soap, "ns:Object", 0, &object, NULL))
-    { soap_smd_end(soap, NULL, NULL); // clean up
+    {
+      soap_smd_end(soap, NULL, NULL); // clean up
       soap_print_fault(soap, stderr);
     }
     else if (soap_smd_end(soap, sig, &siglen))
@@ -255,10 +262,11 @@ must keep it secret) to sign and verify a message:
     int siglen;
     if (soap_smd_begin(soap, alg, key, sizeof(key))
      || soap_out_ns__Object(soap, "ns:Object", 0, &object, NULL))
-    { soap_smd_end(soap, NULL, NULL); // clean up
+    {
+      soap_smd_end(soap, NULL, NULL); // clean up
       soap_print_fault(soap, stderr);
     }
-    else if {soap_smd_end(soap, sig, &siglen))
+    else if (soap_smd_end(soap, sig, &siglen))
       soap_print_fault(soap, stderr);
     else
       ... // sig holds the signature
@@ -277,7 +285,8 @@ algorithms:
     int digestlen;
     if (soap_smd_begin(soap, alg, NULL, 0)
      || soap_out_ns__Object(soap, "ns:Object", 0, &object, NULL))
-    { soap_smd_end(soap, NULL, NULL); // clean up
+    {
+      soap_smd_end(soap, NULL, NULL); // clean up
       soap_print_fault(soap, stderr);
     }
     else if (soap_smd_end(soap, digest, &digestlen))
@@ -300,7 +309,7 @@ extern "C" {
 
 /******************************************************************************\
  *
- * Static local functions used
+ *      Static protos
  *
 \******************************************************************************/
 
@@ -310,7 +319,7 @@ static int soap_smd_check(struct soap *soap, struct soap_smd_data *data, int err
 
 /******************************************************************************\
  *
- * soap_smd API functions
+ *      soap_smd API functions
  *
 \******************************************************************************/
 
@@ -324,17 +333,22 @@ static int soap_smd_check(struct soap *soap, struct soap_smd_data *data, int err
 
 The values returned for digests are SOAP_SMD_MD5_SIZE, SOAP_SMD_SHA1_SIZE, SOAP_SMD_SHA256_SIZE, SOAP_SMD_SHA512_SIZE.
 */
+SOAP_FMAC1
 size_t
+SOAP_FMAC2
 soap_smd_size(int alg, const void *key)
-{ switch (alg & SOAP_SMD_ALGO)
-  { case SOAP_SMD_SIGN:
+{
+  switch ((alg & SOAP_SMD_ALGO))
+  {
+    case SOAP_SMD_SIGN:
     case SOAP_SMD_VRFY:
       /* OpenSSL EVP_PKEY_size returns size of signatures given a key */
       return EVP_PKEY_size((EVP_PKEY*)key);
     case SOAP_SMD_HMAC:
     case SOAP_SMD_DGST:
-      switch (alg & SOAP_SMD_HASH)
-      { case SOAP_SMD_MD5:
+      switch ((alg & SOAP_SMD_HASH))
+      {
+        case SOAP_SMD_MD5:
           return SOAP_SMD_MD5_SIZE;
         case SOAP_SMD_SHA1:
           return SOAP_SMD_SHA1_SIZE;
@@ -346,8 +360,8 @@ soap_smd_size(int alg, const void *key)
           return SOAP_SMD_SHA384_SIZE;
         case SOAP_SMD_SHA512:
           return SOAP_SMD_SHA512_SIZE;
-	default:
-	  break;
+        default:
+          break;
       }
     default:
       break;
@@ -355,6 +369,8 @@ soap_smd_size(int alg, const void *key)
   return 0;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_smd_begin(struct soap *soap, int alg, const void *key, int keylen)
 @brief Initiates a digest or signature computation.
@@ -364,9 +380,12 @@ soap_smd_size(int alg, const void *key)
 @param[in] keylen is the length of the HMAC key or 0
 @return SOAP_OK, SOAP_EOM, or SOAP_SSL_ERROR
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_smd_begin(struct soap *soap, int alg, const void *key, int keylen)
-{ struct soap_smd_data *data;
+{
+  struct soap_smd_data *data;
   data = (struct soap_smd_data*)SOAP_MALLOC(soap, sizeof(struct soap_smd_data));
   if (!data)
     return soap->error = SOAP_EOM;
@@ -385,7 +404,7 @@ soap_smd_begin(struct soap *soap, int alg, const void *key, int keylen)
   soap_clr_attr(soap);
   /* load the local XML namespaces store */
   soap_set_local_namespaces(soap);
-  if (soap->mode & SOAP_XML_CANONICAL)
+  if ((soap->mode & SOAP_XML_CANONICAL))
     soap->ns = 0; /* for in c14n, we must have all xmlns bindings available */
   else if (!(alg & SOAP_SMD_PASSTHRU))
     soap->ns = 2; /* we don't want leading whitespace in serialized XML */
@@ -393,6 +412,8 @@ soap_smd_begin(struct soap *soap, int alg, const void *key, int keylen)
   return soap_smd_init(soap, data, alg, key, keylen);
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_smd_end(struct soap *soap, char *buf, int *len)
 @brief Completes a digest or signature computation. Also deallocates temporary storage allocated by soap_smd_begin(), so MUST be called after soap_smd_begin().
@@ -403,13 +424,17 @@ soap_smd_begin(struct soap *soap, int alg, const void *key, int keylen)
 @param[out] len points to length of stored digest or signature (when not NULL)
 @return SOAP_OK, SOAP_USER_ERROR, or SOAP_SSL_ERROR
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_smd_end(struct soap *soap, char *buf, int *len)
-{ struct soap_smd_data *data;
+{
+  struct soap_smd_data *data;
   int err;
   data = (struct soap_smd_data*)soap->data[0];
   if (!data)
-  { if (soap->error)
+  {
+    if (soap->error)
       return soap->error;
     return soap->error = SOAP_USER_ERROR;
   }
@@ -428,6 +453,8 @@ soap_smd_end(struct soap *soap, char *buf, int *len)
   return err;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_smd_init(struct soap *soap, struct soap_smd_data *data, int alg, const void *key, int keylen)
 @brief Initiates a (signed) digest computation.
@@ -438,9 +465,12 @@ soap_smd_end(struct soap *soap, char *buf, int *len)
 @param[in] keylen is length of HMAC key (when provided)
 @return SOAP_OK or SOAP_SSL_ERROR
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_smd_init(struct soap *soap, struct soap_smd_data *data, int alg, const void *key, int keylen)
-{ int ok = 1;
+{
+  int ok = 1;
   const EVP_MD *type;
   soap_ssl_init();
   /* the algorithm to use */
@@ -449,21 +479,32 @@ soap_smd_init(struct soap *soap, struct soap_smd_data *data, int alg, const void
   data->key = key;
   /* allocate and init the OpenSSL HMAC or EVP_MD context */
   if ((alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
-  { data->ctx = (void*)SOAP_MALLOC(soap, sizeof(HMAC_CTX));
-    if (!data->ctx)
-      return soap_set_receiver_error(soap, "soap_smd_init() failed", "No context", SOAP_SSL_ERROR);
-    HMAC_CTX_init((HMAC_CTX*)data->ctx);
+  {
+#if (OPENSSL_VERSION_NUMBER < 0x10100000L)
+    data->ctx = (void*)SOAP_MALLOC(soap, sizeof(HMAC_CTX));
+    if (data->ctx)
+      HMAC_CTX_init((HMAC_CTX*)data->ctx);
+#else
+    data->ctx = (void*)HMAC_CTX_new();
+#endif
   }
   else
-  { data->ctx = (void*)SOAP_MALLOC(soap, sizeof(EVP_MD_CTX));
-    if (!data->ctx)
-      return soap_set_receiver_error(soap, "soap_smd_init() failed", "No context", SOAP_SSL_ERROR);
-    EVP_MD_CTX_init((EVP_MD_CTX*)data->ctx);
+  {
+#if (OPENSSL_VERSION_NUMBER < 0x10100000L)
+    data->ctx = (void*)SOAP_MALLOC(soap, sizeof(EVP_MD_CTX));
+    if (data->ctx)
+      EVP_MD_CTX_init((EVP_MD_CTX*)data->ctx);
+#else
+    data->ctx = (void*)EVP_MD_CTX_new();
+#endif
   }
+  if (!data->ctx)
+    return soap_set_receiver_error(soap, "soap_smd_init() failed", "No context", SOAP_SSL_ERROR);
   DBGLOG(TEST, SOAP_MESSAGE(fdebug, "-- SMD Init alg=%x (%p) --\n", alg, data->ctx));
   /* init the digest or signature computations */
-  switch (alg & SOAP_SMD_HASH)
-  { case SOAP_SMD_MD5:
+  switch ((alg & SOAP_SMD_HASH))
+  {
+    case SOAP_SMD_MD5:
       type = EVP_md5();
       break;
     case SOAP_SMD_SHA1:
@@ -486,8 +527,9 @@ soap_smd_init(struct soap *soap, struct soap_smd_data *data, int alg, const void
     default:
       return soap_smd_check(soap, data, 0, "soap_smd_init() failed: cannot load digest");
   }
-  switch (alg & SOAP_SMD_ALGO)
-  { case SOAP_SMD_HMAC:
+  switch ((alg & SOAP_SMD_ALGO))
+  {
+    case SOAP_SMD_HMAC:
       HMAC_Init((HMAC_CTX*)data->ctx, key, keylen, type);
       break;
     case SOAP_SMD_DGST:
@@ -506,6 +548,8 @@ soap_smd_init(struct soap *soap, struct soap_smd_data *data, int alg, const void
   return soap_smd_check(soap, data, ok, "soap_smd_init() failed");
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_smd_update(struct soap *soap, struct soap_smd_data *data, const char *buf, size_t len)
 @brief Updates (signed) digest computation with message part.
@@ -515,14 +559,18 @@ soap_smd_init(struct soap *soap, struct soap_smd_data *data, int alg, const void
 @param[in] len of message part
 @return SOAP_OK or SOAP_SSL_ERROR
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_smd_update(struct soap *soap, struct soap_smd_data *data, const char *buf, size_t len)
-{ int ok = 1;
+{
+  int ok = 1;
   if (!data->ctx)
     return soap_set_receiver_error(soap, "soap_smd_update() failed", "No context", SOAP_SSL_ERROR);
   DBGLOG(TEST, SOAP_MESSAGE(fdebug, "-- SMD Update alg=%x n=%lu (%p) --\n", data->alg, (unsigned long)len, data->ctx));
-  switch (data->alg & SOAP_SMD_ALGO)
-  { case SOAP_SMD_HMAC:
+  switch ((data->alg & SOAP_SMD_ALGO))
+  {
+    case SOAP_SMD_HMAC:
       HMAC_Update((HMAC_CTX*)data->ctx, (const unsigned char*)buf, len);
       break;
     case SOAP_SMD_DGST:
@@ -541,9 +589,11 @@ soap_smd_update(struct soap *soap, struct soap_smd_data *data, const char *buf,
   return soap_smd_check(soap, data, ok, "soap_smd_update() failed");
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_smd_final(struct soap *soap, struct soap_smd_data *data, char *buf, int *len)
-@brief Finalizes (signed) digest computation and returns digest or signature.
+@brief Finalizes (signed) digest computation, delete context and returns digest or signature.
 @param soap context
 @param[in,out] data smdevp engine context
 @param[in] buf contains signature for verification (SOAP_SMD_VRFY algorithms)
@@ -552,16 +602,21 @@ soap_smd_update(struct soap *soap, struct soap_smd_data *data, const char *buf,
 @param[out] len points to length of stored digest or signature (pass NULL if you are not interested in this value)
 @return SOAP_OK or SOAP_SSL_ERROR
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_smd_final(struct soap *soap, struct soap_smd_data *data, char *buf, int *len)
-{ unsigned int n = 0;
+{
+  unsigned int n = 0;
   int ok = 1;
   if (!data->ctx)
     return soap_set_receiver_error(soap, "soap_smd_final() failed", "No context", SOAP_SSL_ERROR);
   if (buf)
-  { /* finalize the digest or signature computation */
-    switch (data->alg & SOAP_SMD_ALGO)
-    { case SOAP_SMD_HMAC:
+  {
+    /* finalize the digest or signature computation */
+    switch ((data->alg & SOAP_SMD_ALGO))
+    {
+      case SOAP_SMD_HMAC:
         HMAC_Final((HMAC_CTX*)data->ctx, (unsigned char*)buf, &n);
         break;
       case SOAP_SMD_DGST:
@@ -572,7 +627,8 @@ soap_smd_final(struct soap *soap, struct soap_smd_data *data, char *buf, int *le
         break;
       case SOAP_SMD_VRFY:
         if (len)
-        { n = (unsigned int)*len;
+        {
+          n = (unsigned int)*len;
           ok = EVP_VerifyFinal((EVP_MD_CTX*)data->ctx, (unsigned char*)buf, n, (EVP_PKEY*)data->key);
         }
         else
@@ -587,19 +643,44 @@ soap_smd_final(struct soap *soap, struct soap_smd_data *data, char *buf, int *le
       *len = (int)n;
   }
   /* cleanup */
-  if ((data->alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
-    HMAC_CTX_cleanup((HMAC_CTX*)data->ctx);
-  else
-    EVP_MD_CTX_cleanup((EVP_MD_CTX*)data->ctx);
-  SOAP_FREE(soap, data->ctx);
-  data->ctx = NULL;
+  soap_smd_cleanup(soap, data);
   /* check and return */
   return soap_smd_check(soap, data, ok, "soap_smd_final() failed");
 }
 
+/**
+@fn void soap_smd_cleanup(struct soap *soap, struct soap_smd_data *data)
+@brief Clear (signed) digest computation and delete context
+@param soap context
+@param[in,out] data smdevp engine context
+*/
+SOAP_FMAC1
+void
+SOAP_FMAC2
+soap_smd_cleanup(struct soap *soap, struct soap_smd_data *data)
+{
+  (void)soap;
+  if (data->ctx)
+  {
+#if (OPENSSL_VERSION_NUMBER < 0x10100000L)
+    if ((data->alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
+      HMAC_CTX_cleanup((HMAC_CTX*)data->ctx);
+    else
+      EVP_MD_CTX_cleanup((EVP_MD_CTX*)data->ctx);
+    SOAP_FREE(soap, data->ctx);
+#else
+    if ((data->alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
+      HMAC_CTX_free((HMAC_CTX*)data->ctx);
+    else
+      EVP_MD_CTX_free((EVP_MD_CTX*)data->ctx);
+#endif
+    data->ctx = NULL;
+  }
+}
+
 /******************************************************************************\
  *
- * Static local functions
+ *      Static local functions
  *
 \******************************************************************************/
 
@@ -614,18 +695,29 @@ soap_smd_final(struct soap *soap, struct soap_smd_data *data, char *buf, int *le
 */
 static int
 soap_smd_check(struct soap *soap, struct soap_smd_data *data, int ok, const char *msg)
-{ if (ok <= 0)
-  { unsigned long r;
+{
+  if (ok <= 0)
+  {
+    unsigned long r;
     while ((r = ERR_get_error()))
-    { ERR_error_string_n(r, soap->msgbuf, sizeof(soap->msgbuf));
+    {
+      ERR_error_string_n(r, soap->msgbuf, sizeof(soap->msgbuf));
       DBGLOG(TEST, SOAP_MESSAGE(fdebug, "-- SMD Error (%d) %s: %s\n", ok, msg, soap->msgbuf));
     }
     if (data->ctx)
-    { if ((data->alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
+    {
+#if (OPENSSL_VERSION_NUMBER < 0x10100000L)
+      if ((data->alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
         HMAC_CTX_cleanup((HMAC_CTX*)data->ctx);
       else
         EVP_MD_CTX_cleanup((EVP_MD_CTX*)data->ctx);
       SOAP_FREE(soap, data->ctx);
+#else
+      if ((data->alg & SOAP_SMD_ALGO) == SOAP_SMD_HMAC)
+        HMAC_CTX_free((HMAC_CTX*)data->ctx);
+      else
+        EVP_MD_CTX_free((EVP_MD_CTX*)data->ctx);
+#endif
       data->ctx = NULL;
     }
     return soap_set_receiver_error(soap, msg, soap->msgbuf, SOAP_SSL_ERROR);
@@ -635,7 +727,7 @@ soap_smd_check(struct soap *soap, struct soap_smd_data *data, int ok, const char
 
 /******************************************************************************\
  *
- * Callbacks registered by plugin
+ *      Callbacks registered by plugin
  *
 \******************************************************************************/
 
@@ -649,14 +741,19 @@ soap_smd_check(struct soap *soap, struct soap_smd_data *data, int ok, const char
 */
 static int
 soap_smd_send(struct soap *soap, const char *buf, size_t len)
-{ int err;
+{
+  int err;
   if (((struct soap_smd_data*)soap->data[0])->alg & SOAP_SMD_PASSTHRU)
-  { if ((err = ((struct soap_smd_data*)soap->data[0])->fsend(soap, buf, len)))
+  {
+    err = ((struct soap_smd_data*)soap->data[0])->fsend(soap, buf, len);
+    if (err)
       return err;
   }
   return soap_smd_update(soap, (struct soap_smd_data*)soap->data[0], buf, len);
 }
 
+/******************************************************************************/
+
 /**
 @fn size_t soap_smd_recv(struct soap *soap, char *buf, size_t len)
 @brief Callback to intercept messages for digest or signature computation/verification.
@@ -667,13 +764,15 @@ soap_smd_send(struct soap *soap, const char *buf, size_t len)
 */
 static size_t
 soap_smd_recv(struct soap *soap, char *buf, size_t len)
-{ size_t ret = ((struct soap_smd_data*)soap->data[0])->frecv(soap, buf, len);
+{
+  size_t ret = ((struct soap_smd_data*)soap->data[0])->frecv(soap, buf, len);
   if (ret && soap_smd_update(soap, (struct soap_smd_data*)soap->data[0], buf, ret))
     return 0;
   return ret;
 }
 
+/******************************************************************************/
+
 #ifdef __cplusplus
 }
 #endif
-
