@@ -113,10 +113,7 @@ unsigned int Factory::create(struct soap *soap, enum t__object object, char *nam
       { ref[handle % POOLSIZE] = r;		// add object to the pool
         r->object = object;			// save type
 	if (name)				// save name (if assigned)
-	{ size_t l = strlen(name);
-	  r->name = (char*)malloc(l + 1);
-	  soap_strcpy(r->name, l + 1, name);
-	}
+	  r->name = strdup(name);
 	else
 	  r->name = NULL;
         r->handle = handle;			// keep handle for verification
