@@ -35,7 +35,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 */
 
 #include "soapcalcProxy.h"
-#include "soapServiceProxy.h"
+#include "soapgmtProxy.h"
 #include "soapmashupService.h"
 #include "mashup.nsmap"
 
@@ -56,7 +56,7 @@ int mashupService::dtx(_XML x, _ns3__commingtotown &response)
 {
   (void)x; /* input param that is always empty is simply ignored */
 
-  ServiceProxy Time("http://www.cs.fsu.edu/~engelen/gmtlitserver.cgi");
+  gmtProxy Time("http://www.cs.fsu.edu/~engelen/gmtlitserver.cgi");
 
   _ns1__gmt gmt;
   _ns1__gmtResponse gmtResponse;
@@ -64,27 +64,24 @@ int mashupService::dtx(_XML x, _ns3__commingtotown &response)
   if (Time.gmt(&gmt, gmtResponse))
     return soap_receiverfault("Cannot connect to GMT server", NULL);
 
-  time_t *now = gmtResponse.param_1;
-
-  if (!now)
-    return soap_receiverfault("Could not retrieve current time", NULL);
+  time_t now = gmtResponse.param_1;
 
   struct tm tm;
 
   memset(&tm, 0, sizeof(struct tm));
   tm.tm_mday = 25;
   tm.tm_mon = 11;
-  tm.tm_year = gmtime(now)->tm_year; // this year
+  tm.tm_year = gmtime(&now)->tm_year; // this year
 
   time_t xmas = soap_timegm(&tm);
 
-  if (xmas < *now)
+  if (xmas < now)
   {
     tm.tm_year++; // xmas just passed, go to next year
     xmas = soap_timegm(&tm);
   }
 
-  double sec = difftime(xmas, *now);
+  double sec = difftime(xmas, now);
   
   calcProxy Calc;
   double days;
