@@ -59,18 +59,22 @@ static int find_selection(const char *value, const char *selections);
 static void print_usage(int argc, char **argv, struct option *options);
 
 struct option *copy_options(const struct option *options)
-{ struct option *p;
+{
+  struct option *p;
   int n;
   for (n = 0; options[n].name; n++)
     ;
   p = (struct option*)malloc((n + 1) * sizeof(struct option));
   if (p)
-  { for (n = 0; options[n].name; n++)
-    { p[n].name = options[n].name;
+  {
+    for (n = 0; options[n].name; n++)
+    {
+      p[n].name = options[n].name;
       p[n].selections = options[n].selections;
       p[n].selected = options[n].selected;
       if (options[n].value)
-      { size_t l = strlen(options[n].value);
+      {
+        size_t l = strlen(options[n].value);
 	p[n].value = (char*)malloc(l + 1);
         soap_strcpy(p[n].value, l + 1, options[n].value);
       }
@@ -86,10 +90,13 @@ struct option *copy_options(const struct option *options)
 }
 
 void free_options(struct option *options)
-{ if (options)
-  { struct option *p;
+{
+  if (options)
+  {
+    struct option *p;
     for (p = options; p->name; p++ )
-    { if (p->value)
+    {
+      if (p->value)
         free(p->value);
     }
     free(options);
@@ -97,15 +104,20 @@ void free_options(struct option *options)
 }
 
 int parse_options(int argc, char **argv, struct option *options)
-{ int i;
+{
+  int i;
   for (i = 1; i < argc; i++)
-  { const char *key, *val;
+  {
+    const char *key, *val;
     key = argv[i];
     if (*key == OPTION_CHAR)
-    { int flag = 1;
+    {
+      int flag = 1;
       while (flag && *++key)
-      { if (*key == '?' || !strcmp(key, "help"))
-        { print_usage(argc, argv, options);
+      {
+        if (*key == '?' || !strcmp(key, "help"))
+        {
+          print_usage(argc, argv, options);
 	  return 1;
         }
 	if (i < argc)
@@ -113,7 +125,8 @@ int parse_options(int argc, char **argv, struct option *options)
 	else
 	  val = NULL;
 	switch (set_option(key, val, options))
-	{ case 2:
+	{
+          case 2:
 	    i++;
 	  case 1:
 	    flag = 0;
@@ -137,27 +150,33 @@ int parse_options(int argc, char **argv, struct option *options)
 }
 
 void query_options(struct soap *soap, struct option *options)
-{ char *s = query(soap); /* get arguments from query string */
+{
+  char *s = soap_query(soap); /* get arguments from query string */
   while (s)
-  { char *key = query_key(soap, &s); /* decode next query string key */
-    char *val = query_val(soap, &s); /* decode next query string value */
+  {
+    char *key = soap_query_key(soap, &s); /* decode next query string key */
+    char *val = soap_query_val(soap, &s); /* decode next query string value */
     if (key)
       set_option(key, val, options);
   }
 }
 
 int load_options(const char *file, const char *name, struct option *options)
-{ struct soap soap;
+{
+  struct soap soap;
   soap_init(&soap);
   if (file)
-  { soap.recvfd = open(file, O_RDONLY);
+  {
+    soap.recvfd = open(file, O_RDONLY);
     if (soap.recvfd < 0)
-    { soap_done(&soap);
+    {
+      soap_done(&soap);
       return EOF;
     }
   }
   if (!soap_begin_recv(&soap) && !soap_element_begin_in(&soap, name, 1, NULL))
-  { struct t__Option t;
+  {
+    struct t__Option t;
     while (soap_in_t__Option(&soap, "option", &t, NULL))
       if (set_option(t.key, t.val, options) < 0)
         ; /* error, just ignore for now */
@@ -172,24 +191,30 @@ int load_options(const char *file, const char *name, struct option *options)
 }
 
 int save_options(const char *file, const char *name, struct option *options)
-{ struct soap soap;
+{
+  struct soap soap;
   soap_init1(&soap, SOAP_XML_TREE);
   soap.namespaces = NULL;
   soap.encodingStyle = NULL;
   if (file)
-  { soap.sendfd = open(file, O_CREAT | O_RDWR, 0644);
+  {
+    soap.sendfd = open(file, O_CREAT | O_RDWR, 0644);
     if (soap.sendfd < 0)
-    { soap_done(&soap);
+    {
+      soap_done(&soap);
       return EOF;
     }
   }
   if (!soap_begin_send(&soap) && !soap_element_begin_out(&soap, name, 0, NULL))
-  { struct option *p;
+  {
+    struct option *p;
     struct t__Option t;
     for (p = options; p->name; p++)
-    { t.val = NULL;
+    {
+      t.val = NULL;
       if (!p->name[0])
-      { if (!p->value)
+      {
+        if (!p->value)
           continue;
 	t.key = NULL;
 	t.val = p->value;
@@ -199,16 +224,19 @@ int save_options(const char *file, const char *name, struct option *options)
       else
         t.key = (char*)p->name;
       if (p->selections && strchr(p->selections, ' '))
-      { const char *s = p->selections - 1;
+      {
+        const char *s = p->selections - 1;
         char *r;
 	int i;
         for (i = p->selected; i > 0; i--)
-        { s = strchr(s + 1, ' ');
+        {
+          s = strchr(s + 1, ' ');
 	  if (!s)
 	    break;
 	}
         if (s)
-	{ t.val = soap_strdup(&soap, s + 1);
+	{
+          t.val = soap_strdup(&soap, s + 1);
           r = strchr(t.val, ' ');
 	  if (r)
 	    *r = '\0';
@@ -232,11 +260,13 @@ int save_options(const char *file, const char *name, struct option *options)
 }
 
 int html_options(struct soap *soap, struct option *options)
-{ struct option *p;
+{
+  struct option *p;
   soap_send(soap, "<table border='0' cellspacing='0' cellpadding='0' bgcolor='#666666' nosave>\n");
   soap_send(soap, "<tr height='10'><td background='btl.gif'></td><td background='bt.gif'></td><td background='bt.gif'></td><td background='bt.gif'></td><td background='bt.gif'></td><td background='bt.gif'></td><td width='10' background='btr.gif'></td><td width='10' height='10' background='obls.gif'></td></tr>");
   for (p = options; p->name; p++)
-  { const char *s, *t, *n;
+  {
+    const char *s, *t, *n;
     int i;
     n = p->name;
     if (n[0] && n[1] == '.')
@@ -244,7 +274,8 @@ int html_options(struct soap *soap, struct option *options)
     s = p->selections;
     soap_send(soap, "<tr><td background='bl.gif'></td><td align='right'>");
     if (!n[0])
-    { if (s)
+    {
+      if (s)
         soap_send(soap, s);
       soap_send(soap, "</td><td></td><td></td><td></td><td>");
       if (p->value)
@@ -252,7 +283,8 @@ int html_options(struct soap *soap, struct option *options)
       soap_send(soap, "</td>");
     }
     else if (!s)
-    { soap_send(soap, n);
+    {
+      soap_send(soap, n);
       soap_send(soap, "</td><td width='10' background='ls.gif'></td><td bgcolor='#FFFFFF'><a href='?");
       soap_send(soap, n);
       if (p->selected)
@@ -261,10 +293,12 @@ int html_options(struct soap *soap, struct option *options)
         soap_send(soap, "'><img src='unchecked.gif' align='absmiddle' border='0'></a></td><td width='10' background='rs.gif'></td><td>off</td>");
     }
     else if (strchr(s, ' '))
-    { soap_send(soap, n);
+    {
+      soap_send(soap, n);
       soap_send(soap, "</td>");
       for (i = 0; ; i++)
-      { t = strchr(s, ' ');
+      {
+        t = strchr(s, ' ');
         if (i == 0)
 	  soap_send(soap, "<td width='10' background='ls.gif'></td><td bgcolor='#FFFFFF'>");
         else
@@ -272,7 +306,8 @@ int html_options(struct soap *soap, struct option *options)
         if (i == p->selected)
           soap_send(soap, "<img src='selected.gif' align='absmiddle' border='0'></td><td width='10' background='rs.gif'></td><td>");
         else
-        { soap_send(soap, "<a href='?");
+        {
+          soap_send(soap, "<a href='?");
           soap_send(soap, n);
           soap_send(soap, "=");
           if (t)
@@ -294,7 +329,8 @@ int html_options(struct soap *soap, struct option *options)
       }
     }
     else
-    { char buf[24];
+    {
+      char buf[24];
       soap_send(soap, n);
       soap_send(soap, "</td><td width='10' background='ls.gif'></td><td bgcolor='#FFFFFF'>&nbsp;</td><td width='10' background='rs.gif'></td><td><input type='text' name='");
       soap_send(soap, n);
@@ -316,27 +352,35 @@ int html_options(struct soap *soap, struct option *options)
 }
 
 int html_form_options(struct soap *soap, struct option *options)
-{ soap_send(soap, "<form action='' method='get' name='form'>");
+{
+  soap_send(soap, "<form action='' method='get' name='form'>");
   html_options(soap, options);
   return soap_send(soap, "</form>");
 }
 
 static int set_option(const char *key, const char *val, struct option *options)
-{ struct option *p;
+{
+  struct option *p;
   if (!key)
-  { for (p = options; p->name; p++)
-    { if (!p->name[0])
-      { if (p->value)
-        { size_t l = strlen(p->value) + strlen(val);
+  {
+    for (p = options; p->name; p++)
+    {
+      if (!p->name[0])
+      {
+        if (p->value)
+        {
+          size_t l = strlen(p->value) + strlen(val);
 	  char *s = (char*)malloc(l + 2);
 	  if (s)
-	  { (SOAP_SNPRINTF(s, l + 2, l + 1), "%s %s", p->value, val);
+	  {
+            (SOAP_SNPRINTF(s, l + 2, l + 1), "%s %s", p->value, val);
 	    free((void*)p->value);
 	    p->value = s;
           }
         }
         else
-        { size_t l = strlen(val);
+        {
+          size_t l = strlen(val);
 	  p->value = (char*)malloc(l + 1);
           if (p->value)
             soap_strcpy(p->value, l + 1, val);
@@ -347,16 +391,20 @@ static int set_option(const char *key, const char *val, struct option *options)
     return -2;
   }
   for (p = options; p->name; p++)
-  { if (p->name[0] && ((p->name[1] == '.' && !strcmp(key, p->name + 2)) || (p->name[1] != '.' && !strcmp(key, p->name))))
-    { if (p->selections)
-      { if (!val)
+  {
+    if (p->name[0] && ((p->name[1] == '.' && !strcmp(key, p->name + 2)) || (p->name[1] != '.' && !strcmp(key, p->name))))
+    {
+      if (p->selections)
+      {
+        if (!val)
           return -1;
         if (set_selection(val, p) < 0)
           return -1;
         return 2;
       }
       if (val && !*val)
-      { p->selected = 0;
+      {
+        p->selected = 0;
         return 2;
       }
       p->selected = 1;
@@ -364,11 +412,15 @@ static int set_option(const char *key, const char *val, struct option *options)
     }
   }
   for (p = options; p->name; p++)
-  { if (p->name[0] == key[0] && p->name[1] == '.')
-    { if (p->selections)
-      { const char *s = key + 1;
+  {
+    if (p->name[0] == key[0] && p->name[1] == '.')
+    {
+      if (p->selections)
+      {
+        const char *s = key + 1;
         if (!s[0])
-        { s = val;
+        {
+          s = val;
           if (!s)
             return -1;
         }
@@ -386,7 +438,8 @@ static int set_option(const char *key, const char *val, struct option *options)
 }
 
 static int set_selection(const char *val, struct option *p)
-{ size_t l;
+{
+  size_t l;
   if (strchr(p->selections, ' '))
     return p->selected = find_selection(val, p->selections);
   if (p->value)
@@ -399,11 +452,13 @@ static int set_selection(const char *val, struct option *p)
 }
 
 static int find_selection(const char *val, const char *selections)
-{ int i = 0;
+{
+  int i = 0;
   const char *s = selections;
   size_t n = strlen(val);
   for (;;)
-  { if (!strncmp(s, val, n) && (s[n] == ' ' || s[n] == '\0'))
+  {
+    if (!strncmp(s, val, n) && (s[n] == ' ' || s[n] == '\0'))
       return i;
     s = strchr(s, ' ');
     if (!s)
@@ -415,14 +470,19 @@ static int find_selection(const char *val, const char *selections)
 }
 
 static void print_usage(int argc, char **argv, struct option *options)
-{ struct option *p;
+{
+  struct option *p;
   fprintf(stderr, "Usage: %s", argv[0]);
   for (p = options; p->name; p++)
-  { if (p->name[0])
-    { int flag = (p->name[1] == '.');
+  {
+    if (p->name[0])
+    {
+      int flag = (p->name[1] == '.');
       if (p->selections)
-      { if (strchr(p->selections, ' '))
-        { if (flag)
+      {
+        if (strchr(p->selections, ' '))
+        {
+          if (flag)
 	    fprintf(stderr, " %c%c[%s]", OPTION_CHAR, p->name[0], p->selections);
           else
 	    fprintf(stderr, " %c%s [%s]", OPTION_CHAR, p->name, p->selections);
