@@ -190,6 +190,9 @@ int main(int argc, char **argv)
     soap->accept_timeout = -100000; /* 100ms timeout: do not block on accept */
     for (;;)
     { /* TCP accept (for UDP simply returns current socket) */
+#if !defined(WITH_UDP) && defined(THREADS_H)
+      struct soap *tsoap;
+#endif
       if (!soap_valid_socket(soap_accept(soap)))
       { if (soap->errnum)
           soap_print_fault(soap, stderr);
@@ -204,7 +207,9 @@ int main(int argc, char **argv)
 
       /* do not spawn threads for UDP, since accept() is a no-op for UDP */
 #if !defined(WITH_UDP) && defined(THREADS_H)
-      THREAD_CREATE(&tid, (void*(*)(void*))process_request, (void*)soap_copy(soap));
+      tsoap = soap_copy(soap);
+      while (THREAD_CREATE(&tid, (void*(*)(void*))process_request, (void*)tsoap))
+        sleep(1);
 #else
 #if !defined(WITH_UDP) && defined(WITH_OPENSSL)
       /* SSL accept */
@@ -739,11 +744,12 @@ int ns__wsrmdemo(struct soap *soap, char *in, struct ns__wsrmdemoResponse *resul
   /* for fatal errors that terminate the sequence, we must call soap_wsrm_sender_fault() before soap_wsrm_check() */
   if (in && !strcmp(in, "error"))
   { /* this is fatal, we terminate the sequence */
+    int err;
     soap_wsrm_sequence_handle seq = soap_wsrm_seq(soap);
-    soap_wsrm_error(soap, seq, wsrm__SequenceTerminated);
+    err = soap_wsrm_error(soap, seq, wsrm__SequenceTerminated);
     soap_wsrm_seq_release(soap, seq);
     printf("\n**** Simulating Server Operation Fatal Error\n");
-    return soap_wsrm_sender_fault(soap, "The demo service wsrmdemo() operation generated a fatal error", NULL);
+    return err;
   }
 
   /* simulate a non-fatal user-defined error, which is can be relayed */
