@@ -85,8 +85,8 @@ at the end of the options:
 
 */
 
-#include "wsaapi.h"
 #include "wstapi.h"
+#include "wsaapi.h"
 #include "wsseapi.h"
 #include "wst.nsmap"
 
@@ -478,7 +478,7 @@ __wst__RequestSecurityToken(struct soap *soap, struct wst__RequestSecurityTokenT
     /* this part if for testing the validity of the SAML token only and can be omitted */
     /* assumes soap->cacert = "cacert.pem"; */ /* already set with soap_ssl_server_context() */
     if (soap_wsse_verify_saml2(soap, assertion))
-      return soap_receiver_fault(soap, "Cannot sign SAML token with outdated key and/or certificate", NULL);
+      return soap_receiver_fault(soap, "Cannot sign SAML token (invalid key or certificate)", NULL);
 
     response->RequestedSecurityToken = (wst__RequestedSecurityTokenType*)soap_malloc(soap, sizeof(wst__RequestedSecurityTokenType));
     if (!response->RequestedSecurityToken)
@@ -504,6 +504,20 @@ __wst__RequestSecurityToken(struct soap *soap, struct wst__RequestSecurityTokenT
   return soap_wsa_reply(soap, NULL, soap_wst_rstr_action);
 }
 
+SOAP_FMAC5
+int
+SOAP_FMAC6
+__wst__RequestSecurityTokenResponse(struct soap *soap, struct wst__RequestSecurityTokenResponseType *request, struct wst__RequestSecurityTokenResponseCollectionType *response)
+{ 
+  (void)soap;
+  (void)request;
+  (void)response;
+
+  /* service logic goes here to populate RSTRC */
+
+  return soap_wsa_reply(soap, NULL, soap_wst_rstrc_action);
+}
+
 SOAP_FMAC5
 int
 SOAP_FMAC6
