@@ -44,9 +44,10 @@ typedef char	*xsd__anyURI,
 		*xsd__string;
 typedef bool	xsd__boolean;
 
-extern class ostream;
-extern class istream;
+extern class std::ostream;
+extern class std::istream;
 
 #include "includes.h"
 
+extern class MapOfStringToString;
 extern class SetOfString;
