@@ -46,8 +46,8 @@ extern const char *qname_token(const char*, const char*);
 int mime__multipartRelated::traverse(wsdl__definitions& definitions)
 {
   if (vflag)
-    cerr << "Analyzing mime multpartRelated " << endl;
-  for (vector<mime__part>::iterator pt = part.begin(); pt != part.end(); ++pt)
+    std::cerr << "Analyzing mime multpartRelated " << std::endl;
+  for (std::vector<mime__part>::iterator pt = part.begin(); pt != part.end(); ++pt)
     (*pt).traverse(definitions);
   return SOAP_OK;
 }
@@ -61,8 +61,8 @@ int mime__multipartRelated::traverse(wsdl__definitions& definitions)
 int mime__part::traverse(wsdl__definitions& definitions)
 {
   if (vflag)
-    cerr << "Analyzing mime part " << endl;
-  for (vector<soap__header>::iterator hd = soap__header_.begin(); hd != soap__header_.end(); ++hd)
+    std::cerr << "Analyzing mime part " << std::endl;
+  for (std::vector<soap__header>::iterator hd = soap__header_.begin(); hd != soap__header_.end(); ++hd)
     (*hd).traverse(definitions);
   return SOAP_OK;
 }
