@@ -315,6 +315,7 @@ class xs__simpleType
         xs__union                       *union_;                // choice
   private:
         xs__schema                      *schemaRef;
+        std::vector<xs__complexType*>   complextype_extensions;
         std::vector<xsd__QName>         extensions;
         std::vector<xsd__QName>         restrictions;
         int                             level;
@@ -327,7 +328,7 @@ class xs__simpleType
         int                             baseLevel();
         void                            mark();
         bool                            is_used() const;
-        void                            add_extension(xs__schema&, xsd__NCName);
+        void                            add_extension(xs__complexType*, xs__schema&, xsd__NCName);
         void                            add_restriction(xs__schema&, xsd__NCName);
         const std::vector<xsd__QName>&  get_extensions() const;
         const std::vector<xsd__QName>&  get_restrictions() const;
@@ -480,6 +481,7 @@ class xs__complexType
         std::vector<xs__assert>         assert;                 // XSD 1.1
   private:
         xs__schema                      *schemaRef;
+        std::vector<xs__complexType*>   complextype_extensions;
         std::vector<xsd__QName>         extensions;
         std::vector<xsd__QName>         restrictions;
         int                             level;
@@ -492,8 +494,8 @@ class xs__complexType
         int                             baseLevel();
         void                            mark();
         bool                            is_used() const;
-        void                            add_extension(xs__schema&, xsd__QName);
-        void                            add_restriction(xs__schema&, xsd__QName);
+        void                            add_extension(xs__complexType*, xs__schema&, xsd__NCName);
+        void                            add_restriction(xs__schema&, xsd__NCName);
         const std::vector<xsd__QName>&  get_extensions() const;
         const std::vector<xsd__QName>&  get_restrictions() const;
 };
@@ -600,13 +602,13 @@ class xs__schema
   public:
                                         xs__schema();
                                         xs__schema(struct soap*);
-                                        xs__schema(struct soap*, const char*, const char*);
+                                        xs__schema(struct soap*, const char*, const char*, const char*);
         virtual                         ~xs__schema();
         int                             get(struct soap*);      // getter is triggered after parsing
         int                             preprocess();
         int                             insert(xs__schema&);
         int                             traverse();
-        int                             read(const char*, const char*);
+        int                             read(const char*, const char*, const char*);
         void                            sourceLocation(const char*);
         const char*                     sourceLocation();
         char*                           absoluteLocation(const char*) const;
@@ -623,10 +625,10 @@ class xs__schema
         const SetOfString&              builtinAttributes() const;
         bool                            empty() const;
         void                            mark();
-        friend ostream&                 operator<<(ostream&, const xs__schema&);
-        friend istream&                 operator>>(istream&, xs__schema&);
+        friend std::ostream&            operator<<(std::ostream&, const xs__schema&);
+        friend std::istream&            operator>>(std::istream&, xs__schema&);
 };
 
-extern ostream &operator<<(ostream &o, const xs__schema &e);
-extern istream &operator>>(istream &i, xs__schema &e);
+extern std::ostream &operator<<(std::ostream &o, const xs__schema &e);
+extern std::istream &operator>>(std::istream &i, xs__schema &e);
 
